@@ -2,6 +2,7 @@ mod bindings;
 pub mod cli;
 mod cmd_log;
 pub mod config;
+mod file_watcher;
 mod git;
 mod git2_opts;
 mod items;
@@ -18,12 +19,15 @@ mod tests;
 mod ui;
 
 use crossterm::event::{self, Event, KeyCode, KeyEvent, KeyEventState, KeyModifiers};
+use file_watcher::FileWatcher;
 use git2::Repository;
 use items::Item;
 use ops::Action;
 use std::{error::Error, path::PathBuf, process::Command, rc::Rc, time::Duration};
 use term::Term;
 
+pub const LOG_FILE_NAME: &str = "gitu.log";
+
 //                                An overview of Gitu's ui and terminology:
 //
 //                Screen (src/screen/*)
@@ -63,6 +67,11 @@ use term::Term;
 
 pub type Res<T> = Result<T, Box<dyn Error>>;
 
+pub enum GituEvent {
+    Term(Event),
+    FileUpdate,
+}
+
 pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
     log::debug!("Finding git dir");
     let dir = PathBuf::from(
@@ -80,13 +89,13 @@ pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
     repo.set_workdir(&dir, false)?;
 
     log::debug!("Initializing config");
-    let config = config::init_config()?;
+    let config = Rc::new(config::init_config()?);
 
     log::debug!("Creating initial state");
-    let mut state = state::State::create(Rc::new(repo), term.size()?, args, Rc::new(config), true)?;
+    let mut state = state::State::create(Rc::new(repo), term.size()?, args, config.clone(), true)?;
 
     log::debug!("Initial update");
-    state.update(term, &[Event::FocusGained])?;
+    state.update(term, &[GituEvent::Term(Event::FocusGained)])?;
 
     if args.print {
         return Ok(());
@@ -99,13 +108,23 @@ pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
         handle_initial_send_keys(&keys, &mut state, term)?;
     }
 
+    let watcher = config
+        .general
+        .refresh_on_file_change
+        .enabled
+        .then(|| FileWatcher::new(&dir))
+        .transpose()?;
+
     while !state.quit {
-        let events = if event::poll(Duration::from_millis(100))? {
-            vec![event::read()?]
+        let mut events = if event::poll(Duration::from_millis(100))? {
+            vec![GituEvent::Term(event::read()?)]
         } else {
             vec![]
         };
 
+        if watcher.as_ref().is_some_and(|w| w.pending_updates()) {
+            events.push(GituEvent::FileUpdate);
+        }
         state.update(term, &events)?;
     }
 
@@ -130,12 +149,12 @@ fn handle_initial_send_keys(
     let initial_events = keys
         .iter()
         .map(|(mods, key)| {
-            Event::Key(KeyEvent {
+            GituEvent::Term(Event::Key(KeyEvent {
                 code: *key,
                 modifiers: *mods,
                 kind: event::KeyEventKind::Press,
                 state: KeyEventState::NONE,
-            })
+            }))
         })
         .collect::<Vec<_>>();
 
