@@ -33,6 +33,7 @@ use crate::screen::Screen;
 use crate::term::Term;
 use crate::ui;
 
+use super::GituEvent;
 use super::Res;
 
 pub(crate) struct State {
@@ -97,15 +98,15 @@ impl State {
         })
     }
 
-    pub fn update(&mut self, term: &mut Term, events: &[Event]) -> Res<()> {
+    pub fn update(&mut self, term: &mut Term, events: &[GituEvent]) -> Res<()> {
         for event in events {
             match *event {
-                Event::Resize(w, h) => {
+                GituEvent::Term(Event::Resize(w, h)) => {
                     for screen in self.screens.iter_mut() {
                         screen.size = Size::new(w, h);
                     }
                 }
-                Event::Key(key) => {
+                GituEvent::Term(Event::Key(key)) => {
                     if self.prompt.state.is_focused() {
                         self.prompt.state.handle_key_event(key)
                     } else if key.kind == KeyEventKind::Press {
@@ -116,6 +117,9 @@ impl State {
                         self.handle_key_input(term, key)?;
                     }
                 }
+                GituEvent::FileUpdate => {
+                    self.screen_mut().update()?;
+                }
                 _ => (),
             }
 
@@ -302,7 +306,17 @@ impl State {
 
         cmd.current_dir(self.repo.workdir().expect("No workdir"));
 
-        cmd.stdin(Stdio::piped());
+        // Redirect stderr so we can capture it via `Child::wait_with_output()`
+        cmd.stderr(Stdio::piped());
+
+        // git will have staircased output in raw mode (issue #290)
+        // disable raw mode temporarily for the git command
+        term.backend().disable_raw_mode()?;
+
+        // If we don't show the cursor prior spawning (thus restore the default
+        // state), the cursor may be missing in $EDITOR.
+        term.show_cursor()?;
+
         let child = cmd.spawn()?;
 
         let out = child.wait_with_output()?;
@@ -312,6 +326,9 @@ impl State {
 
         self.current_cmd_log.push_cmd_with_output(&cmd, out_utf8);
 
+        // restore the raw mode
+        term.backend().enable_raw_mode()?;
+
         // Prevents cursor flash when exiting editor
         term.hide_cursor()?;
 
